==> apache-ignite-2.13.0-src.zip: apache-ignite-2.13.0-src/modules/zookeeper/src/main/java/org/apache/ignite/spi/discovery/zk/internal/ZkDiscoveryNodeJoinEventData.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.spi.discovery.zk.internal;

import java.util.List;

/**
 *
 */
class ZkDiscoveryNodeJoinEventData extends ZkDiscoveryEventData {
    /** */
    private static final long serialVersionUID = 0L;

    /** */
    final List<ZkJoinedNodeEvtData> joinedNodes;

    /** */
    final int dataForJoinedPartCnt;

    /**
     * @param evtId Event ID.
     * @param topVer Topology version.
     * @param joinedNodes Joined nodes data.
     * @param dataForJoinedPartCnt Data for joined part count.
     */
    ZkDiscoveryNodeJoinEventData(
        long evtId,
        long topVer,
        List<ZkJoinedNodeEvtData> joinedNodes,
        int dataForJoinedPartCnt)
    {
        super(evtId, ZK_EVT_NODE_JOIN, topVer);

        this.joinedNodes = joinedNodes;
        this.dataForJoinedPartCnt = dataForJoinedPartCnt;
    }

    /** {@inheritDoc} */
    @Override public String toString() {
        return "ZkDiscoveryNodeJoinEventData [" +
            "evtId=" + eventId() +
            ", topVer=" + topologyVersion() +
            ", nodes=" + joinedNodes + ']';
    }
}

==> apache-ignite-2.17.0-src.zip: apache-ignite-2.17.0-src/modules/zookeeper/src/main/java/org/apache/ignite/spi/discovery/zk/internal/ZkDiscoveryNodeJoinEventData.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.spi.discovery.zk.internal;

import java.util.List;

/**
 *
 */
class ZkDiscoveryNodeJoinEventData extends ZkDiscoveryEventData {
    /** */
    private static final long serialVersionUID = 0L;

    /** */
    final List<ZkJoinedNodeEvtData> joinedNodes;

    /** */
    final int dataForJoinedPartCnt;

    /**
     * @param evtId Event ID.
     * @param topVer Topology version.
     * @param joinedNodes Joined nodes data.
     * @param dataForJoinedPartCnt Data for joined part count.
     */
    ZkDiscoveryNodeJoinEventData(
        long evtId,
        long topVer,
        List<ZkJoinedNodeEvtData> joinedNodes,
        int dataForJoinedPartCnt
    ) {
        super(evtId, ZK_EVT_NODE_JOIN, topVer);

        this.joinedNodes = joinedNodes;
        this.dataForJoinedPartCnt = dataForJoinedPartCnt;
    }

    /** {@inheritDoc} */
    @Override public String toString() {
        return "ZkDiscoveryNodeJoinEventData [" +
            "evtId=" + eventId() +
            ", topVer=" + topologyVersion() +
            ", nodes=" + joinedNodes + ']';
    }
}
